@@ -1528,6 +1528,64 @@ Note: this field may return `null`, indicating that no valid value is obtained.
         self.CreateUin = params.get("CreateUin")
 
 
+class StartMatchingBackfillRequest(AbstractModel):
+    """StartMatchingBackfill request structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param MatchCode: MatchCode
+        :type MatchCode: str
+        :param Players: Player information
+        :type Players: list of Player
+        :param GameServerSessionId: Game server session ID. It should contain 1 to 256 ASCII characters.
+        :type GameServerSessionId: str
+        :param MatchTicketId: MatchTicket ID, which can contain 1 to 128 characters. This parameter is left empty by default, and in this case, MatchTicket ID will be automatically generated by GPM.
+        :type MatchTicketId: str
+        """
+        self.MatchCode = None
+        self.Players = None
+        self.GameServerSessionId = None
+        self.MatchTicketId = None
+
+
+    def _deserialize(self, params):
+        self.MatchCode = params.get("MatchCode")
+        if params.get("Players") is not None:
+            self.Players = []
+            for item in params.get("Players"):
+                obj = Player()
+                obj._deserialize(item)
+                self.Players.append(obj)
+        self.GameServerSessionId = params.get("GameServerSessionId")
+        self.MatchTicketId = params.get("MatchTicketId")
+
+
+class StartMatchingBackfillResponse(AbstractModel):
+    """StartMatchingBackfill response structure.
+
+    """
+
+    def __init__(self):
+        """
+        :param MatchTicket: MatchTicket
+Note: this field may return `null`, indicating that no valid values can be obtained.
+        :type MatchTicket: :class:`tencentcloud.gpm.v20200820.models.MatchTicket`
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
+        :type RequestId: str
+        """
+        self.MatchTicket = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("MatchTicket") is not None:
+            self.MatchTicket = MatchTicket()
+            self.MatchTicket._deserialize(params.get("MatchTicket"))
+        self.RequestId = params.get("RequestId")
+
+
 class StartMatchingRequest(AbstractModel):
     """StartMatching request structure.
 
